/*
 * Copyright (c) 2005-2007 CodeDroids ApS (http://www.codedroids.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * For further information about CodeDroids ApS, please see the
 * company website: http://www.codedroids.com
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * $LastChangedRevision: 181 $
 * $LastChangedDate: 2007-06-20 11:24:06 +0200 (Wed, 20 Jun 2007) $
 * 
 */

package com.codedroids.oc.freemarker;

import freemarker.template.*;
import freemarker.ext.servlet.*;
import org.opencms.file.*;
import org.opencms.main.*;
import org.opencms.jsp.*;
import java.util.*;

public class CmsHash extends SimpleHash {

	static final long serialVersionUID =1L;
	
	transient private CmsJspActionElement cms;
	transient private CmsObject cmso;
	String resName;
	Map defaults;
	boolean search;
	Set lazySet;
	
	public CmsHash() {
		super();
		this.lazySet = new HashSet();
		this.lazySet.add("cms");
		this.lazySet.add("utils");
		this.lazySet.add("resource");
		this.lazySet.add("request");
		this.lazySet.add("parameters");
		this.lazySet.add("properties");
		this.lazySet.add("localProperties");
	}
	
	public CmsHash(CmsJspActionElement cms) {
		this();
		this.setCms(cms); 
	}
	
	public CmsHash(CmsJspActionElement cms, Map extra) {
		this(cms);
        this.putAll(extra);
	}
	
	public void setCms(CmsJspActionElement cms) {
		this.cms = cms;
		this.cmso = cms.getCmsObject();
		this.resName = cmso.getRequestContext().getUri();		
	}
	
	public CmsJspActionElement getCms() {
		return cms;
	}

	public TemplateModel get(String key) throws TemplateModelException {
		TemplateModel result = super.get(key);
		if(result == null && lazySet.contains(key)) {
			if("cms".equals(key)) {
				SimpleHash cmsHash = new SimpleHash();
				cmsHash.put("link", new CmsLinkMethod(cms));
				cmsHash.put("property", new CmsPropertyMethod(cms));
				cmsHash.put("user", new CmsUserMethod(cms));
				cmsHash.put("info", new CmsInfoMethod(cms));
				cmsHash.put("label", new CmsLabelMethod(cms));
				this.put(key, cmsHash);
			}
			else if("utils".equals(key)) {
				SimpleHash utilHash = new SimpleHash();
				utilHash.put("dateFromLong", new DateFromLongMethod());
				utilHash.put("absLink", new AbsoluteLinkMethod(cms));
				utilHash.put("removeSiteRoot", new RemoveSiteRootMethod(cms));
				utilHash.put("setSiteRoot", new SetSiteRootMethod(cms));
				this.put(key, utilHash);
			}
			else if("resource".equals(key)) {
				try {
					this.put(key, cmso.readResource(cmso.getRequestContext().getUri()));
				} catch (CmsException ce) {
					// then let it be null which is an ok interpretation of no resource...
				}
			}
			else if("request".equals(key)) {
				this.put(key, new HttpRequestHashModel(cms.getRequest(), ObjectWrapper.DEFAULT_WRAPPER));
			}
			else if("parameters".equals(key)) {
				this.put(key, new HttpRequestParametersHashModel(cms.getRequest()));
			}
			else if("properties".equals(key)) {
				this.put(key, new VFSResourcePropertyModel(cmso, cmso.getRequestContext().getUri(), true));
			}
			else if("localProperties".equals(key)) {
				this.put(key, new VFSResourcePropertyModel(cmso, cmso.getRequestContext().getUri(), false));
			}
			result = super.get(key);
		}
		return result;
	}
}
