/*
 * Copyright (c) 2005-2007 CodeDroids ApS (http://www.codedroids.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * For further information about CodeDroids ApS, please see the
 * company website: http://www.codedroids.com
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * $LastChangedRevision: 118 $
 * $LastChangedDate: 2007-02-20 17:26:56 +0100 (Tue, 20 Feb 2007) $
 * 
 */

package com.codedroids.oc.freemarker;

import freemarker.cache.TemplateLoader;
import org.opencms.file.CmsObject;
import org.opencms.file.CmsFile;
import java.io.*;

public class VFSTemplateLoader implements TemplateLoader {

	private CmsObject co;
	private String baseDir;
	
	public VFSTemplateLoader(CmsObject co) 
	{
		this(co, "/");
	}
	
	public VFSTemplateLoader(CmsObject co, String baseDir) 
	{
		super();
		this.co = co;
		if(baseDir.endsWith("/"))
			this.baseDir = baseDir;
		else 
			this.baseDir = baseDir + "/";
	}

	public Object findTemplateSource(String name) throws IOException 
	{
		try {
			CmsFile f = co.readFile(baseDir + name);
			return f;
		} catch (Exception e) {
			return null; // just return since it may be okay not to find it due to the localized lookup feature
		}
	}
	
	public long getLastModified(java.lang.Object templateSource) 
	{
		CmsFile f = (CmsFile)templateSource;
		return f.getDateLastModified();
	}
	
	public Reader getReader(java.lang.Object templateSource, java.lang.String encoding) throws IOException 
	{
		CmsFile f = (CmsFile)templateSource;
		ByteArrayInputStream is = new ByteArrayInputStream(f.getContents());
		return new InputStreamReader(is, encoding);
	}
	
	public void closeTemplateSource(Object templateSource)
	{
		// Do nothing.
	}
}
